/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A tyTuple__JfHvHzMrhKkWAUvQKe0i1A;
typedef struct tyObject_Env_modulegraphsdotnim_ModuleGraph___diB2NTuAIWY0FO9c5IUJRGg tyObject_Env_modulegraphsdotnim_ModuleGraph___diB2NTuAIWY0FO9c5IUJRGg;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct NimStringDesc NimStringDesc;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;

/* section: NIM_merge_TYPES */
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A {
void* Field0;
tyObject_Env_modulegraphsdotnim_ModuleGraph___diB2NTuAIWY0FO9c5IUJRGg* Field1;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* tyArray__o8KQyTFgNQGvsJZYtdEsgA[8192];
struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw {
tyArray__o8KQyTFgNQGvsJZYtdEsgA buckets;
NI wordCounter;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* idAnon;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* idDelegator;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* emptyIdent;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
typedef NimStringDesc* tyArray__TLUjAhnMfzBtYkb49czB0KA[64];
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__DfgJFJEYoj4YBAHLZPl5lQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__48JTohSgTy339bRxHzUD8KA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__bWZXqEvLFwhLvAqSRoFNgQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__PzqTLBFNawCGiqTk0UORYw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__KfdHSsl8vyUCSI9b3inBcww)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__2n9b6ELeZfbbP5wqNYm7VyA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* x);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__w3hW0l8agm6xMv9afJe9aiRw)(NI initialSize, tyObject_Table__fdKWDDO1P17zvuQPReVgRA* Result);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
N_LIB_PRIVATE N_NIMCALL(void, initTable__CaVonymNJD1dGAhApMbV2g)(NI initialSize, tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ* Result);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createMagic__MzNJxZ0htpjW89c9b2wBN5rQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___ylbbr8jh8vWSg9baXjEpyQQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, initTable__nbdg1XkakWibhw6meLxFVg)(NI initialSize, tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__2gDElK9agmPOHa6UVPYygZg)(NI initialSize, tyObject_Table__NttoEzoiq5CiphZe81oadg* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__Qp2wzR51fqIFP8LjGKEktQ)(NI initialSize, tyObject_Table__nagDFX4QHx0s6Fvma9blmSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__SkNpgL9chjNeAljrvOTzV2Q)(NI initialSize, tyObject_Table__IioUJGdqPI6xC7S7QF8MBw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__DqzDsZYrt3ZYs1snAP7Uqw)(NI initialSize, tyObject_Table__G1v8c16HePOldLeucwe05Q* Result);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
static N_INLINE(NI, dependsOn__y2JUh31ZM6T6tGwecq9aq6Amodulegraphs)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKeyOrPut__WdnGwzJoNnsIHUzxAKLE9aw)(tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ* t, NI32 key, NI32 val);
N_LIB_PRIVATE N_NIMCALL(void, transitiveClosure__8rdBNRdm9adY9cVlc8PBy62w)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* g, NI n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toBase64a__vUDU9aiIT31gTQwrDG6XJ8Q)(NCSTRING s, NI len);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);

/* section: NIM_merge_DATA */
N_LIB_PRIVATE TNimType NTI__RZI3hCs0FTPYx8StfC81qQ_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
N_LIB_PRIVATE TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
extern TNimType NTI__f07aOS3dr28kGa5wcE29aFA_;
extern TNimType NTI__PQrmFm4BXFkFSVOUl1ojSg_;
extern TNimType NTI__sVg18TP9cLifHyygRe9cro9aA_;
N_LIB_PRIVATE TNimType NTI__48JTohSgTy339bRxHzUD8KA_;
extern TNimType NTI__fdKWDDO1P17zvuQPReVgRA_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTI__e2Ciu0s1q49aVQ7ULXy7l9bQ_;
extern TNimType NTI__0vJvi4uHbxjbxlkkX7P1EA_;
extern TNimType NTI__a8lycfSA25OQltN3OMeBsA_;
extern TNimType NTI__lnkYNZP9asc88UfiEGjLrbA_;
N_LIB_PRIVATE TNimType NTI__In3g79a0qTcRmbTbJp9ba9ctg_;
extern TNimType NTI__vr5DoT1jILTGdRlYv1OYpw_;
extern TNimType NTI__HsJiUUcO9cHBdUCi0HwkSTA_;
N_LIB_PRIVATE TNimType NTI__quA39a2QdEQU9cSEIUSibApQ_;
N_LIB_PRIVATE TNimType NTI__bWZXqEvLFwhLvAqSRoFNgQ_;
extern TNimType NTI__AgIT5feFR9a9aoVjv9cx2rOtg_;
N_LIB_PRIVATE TNimType NTI__OLX364rHC66WkzRbMp49aQg_;
N_LIB_PRIVATE TNimType NTI__6GDJmNRiFxkWAAdMgUie8g_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
extern TNimType NTI__sdH7TnbKACuAzE7DBabnCA_;
extern TNimType NTI__IioUJGdqPI6xC7S7QF8MBw_;
extern TNimType NTI__G1v8c16HePOldLeucwe05Q_;
N_LIB_PRIVATE TNimType NTI__c6vdo1yHyj19b9bS17tijS2w_;
N_LIB_PRIVATE TNimType NTI__d5yEkT9aXkAtHvVerr7IeCQ_;
N_LIB_PRIVATE TNimType NTI__sP1I7TbCn358eLy9bX4IphA_;
extern TNimType NTI__0Y2brGGKD9bV6GJLXT9aUDgA_;
extern TNimType NTI__NttoEzoiq5CiphZe81oadg_;
extern TNimType NTI__nagDFX4QHx0s6Fvma9blmSg_;
N_LIB_PRIVATE TNimType NTI__euPCXX9bc3XzndEhYlqNS7g_;
N_LIB_PRIVATE TNimType NTI__8ooe5vdoqmvpHnfXV29bP3w_;
N_LIB_PRIVATE TNimType NTI__A7Sdoem70tRxSEmKrf9cmyg_;
N_LIB_PRIVATE TNimType NTI__EAEKmBUgKFg29agoUGtzDEQ_;
N_LIB_PRIVATE TNimType NTI__PzqTLBFNawCGiqTk0UORYw_;
N_LIB_PRIVATE TNimType NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_;
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
N_LIB_PRIVATE TNimType NTI__3TeLOx1euAsRk3YCaQCuPg_;
N_LIB_PRIVATE TNimType NTI__KfdHSsl8vyUCSI9b3inBcww_;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_6, "not", 3);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_7, "contains", 8);
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__Hb6rFM0ecvtlLf2kv9aU75w_;
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_8, "__", 2);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_9, "A", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_10, "B", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_11, "C", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_12, "D", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_13, "E", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_14, "F", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_15, "G", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_16, "H", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_17, "I", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_18, "J", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_19, "K", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_20, "L", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_21, "M", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_22, "N", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_23, "O", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_24, "P", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_25, "Q", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_26, "R", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_27, "S", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_28, "T", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_29, "U", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_30, "V", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_31, "W", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_32, "X", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_33, "Y", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_34, "Z", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_35, "a", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_36, "b", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_37, "c", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_38, "d", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_39, "e", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_40, "f", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_41, "g", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_42, "h", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_43, "i", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_44, "j", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_45, "k", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_46, "l", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_47, "m", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_48, "n", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_49, "o", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_50, "p", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_51, "q", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_52, "r", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_53, "s", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_54, "t", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_55, "u", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_56, "v", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_57, "w", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_58, "x", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_59, "y", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_60, "z", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_61, "0", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_62, "1", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_63, "2", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_64, "3", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_65, "4", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_66, "5", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_67, "6", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_68, "7", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_69, "8", 1);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_70, "9a", 2);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_71, "9b", 2);
STRING_LITERAL(TM__vJDjRhiQWnfbAi9csscWSug_72, "9c", 2);
N_LIB_PRIVATE NIM_CONST tyArray__TLUjAhnMfzBtYkb49czB0KA cb64__FJ8E6h9cW5QacFEq9be79cTmg = {((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_9),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_10),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_11),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_12),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_13),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_14),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_15),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_16),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_17),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_18),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_19),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_20),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_21),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_22),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_23),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_24),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_25),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_26),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_27),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_28),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_29),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_30),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_31),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_32),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_33),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_34),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_35),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_36),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_37),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_38),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_39),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_40),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_41),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_42),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_43),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_44),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_45),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_46),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_47),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_48),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_49),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_50),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_51),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_52),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_53),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_54),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_55),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_56),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_57),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_58),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_59),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_60),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_61),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_62),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_63),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_64),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_65),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_66),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_67),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_68),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_69),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_70),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_71),
((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_72)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tySequence__DfgJFJEYoj4YBAHLZPl5lQ)(void* p, NI op) {
	tySequence__DfgJFJEYoj4YBAHLZPl5lQ* a;
	NI T1_;
	a = (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tySequence__48JTohSgTy339bRxHzUD8KA)(void* p, NI op) {
	tySequence__48JTohSgTy339bRxHzUD8KA* a;
	NI T1_;
	a = (tySequence__48JTohSgTy339bRxHzUD8KA*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__bWZXqEvLFwhLvAqSRoFNgQ)(void* p, NI op) {
	tySequence__bWZXqEvLFwhLvAqSRoFNgQ* a;
	NI T1_;
	a = (tySequence__bWZXqEvLFwhLvAqSRoFNgQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__PzqTLBFNawCGiqTk0UORYw)(void* p, NI op) {
	tySequence__PzqTLBFNawCGiqTk0UORYw* a;
	NI T1_;
	a = (tySequence__PzqTLBFNawCGiqTk0UORYw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tyRef__KfdHSsl8vyUCSI9b3inBcww)(void* p, NI op) {
	tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* a;
	NI T1_;
	NI T2_;
	NI T3_;
	a = (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*)p;
	nimGCvisit((void*)(*a).modules, op);
	nimGCvisit((void*)(*a).packageSyms.data, op);
	nimGCvisit((void*)(*a).deps.head, op);
	nimGCvisit((void*)(*a).deps.data, op);
	T1_ = (NI)0;
	nimGCvisit((void*)(*a).importDeps.data, op);
	nimGCvisit((void*)(*a).inclToMod.data, op);
	nimGCvisit((void*)(*a).importStack, op);
	nimGCvisit((void*)(*a).backend, op);
	nimGCvisit((void*)(*a).config, op);
	nimGCvisit((void*)(*a).cache, op);
	nimGCvisit((void*)(*a).vm, op);
	nimGCvisit((void*)(*a).doStopCompile.ClE_0, op);
	nimGCvisit((void*)(*a).usageSym, op);
	nimGCvisit((void*)(*a).owners, op);
	nimGCvisit((void*)(*a).methods, op);
	nimGCvisit((void*)(*a).systemModule, op);
	T2_ = (NI)0;
	for (T2_ = 0; T2_ < 64; T2_++) {
	nimGCvisit((void*)(*a).sysTypes[T2_], op);
	}
	nimGCvisit((void*)(*a).compilerprocs.data, op);
	nimGCvisit((void*)(*a).exposed.data, op);
	T3_ = (NI)0;
	for (T3_ = 0; T3_ < 70; T3_++) {
	nimGCvisit((void*)(*a).intTypeCache[T3_], op);
	}
	nimGCvisit((void*)(*a).opContains, op);
	nimGCvisit((void*)(*a).opNot, op);
	nimGCvisit((void*)(*a).emptyNode, op);
	nimGCvisit((void*)(*a).canonTypes.data, op);
	nimGCvisit((void*)(*a).symBodyHashes.data, op);
	nimGCvisit((void*)(*a).cacheSeqs.data, op);
	nimGCvisit((void*)(*a).cacheCounters.data, op);
	nimGCvisit((void*)(*a).cacheTables.data, op);
	nimGCvisit((void*)(*a).passes, op);
	nimGCvisit((void*)(*a).globalDestructors, op);
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createMagic__MzNJxZ0htpjW89c9b2wBN5rQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, name);
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12), T1_, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, 0);
	(*result).magic = m;
	(*result).flags = IL64(4398046511104);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___ylbbr8jh8vWSg9baXjEpyQQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*, newModuleGraph__i9b4NK8jPhAUAsvbtMitNLw)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config) {
	tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* result;
	tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* T1_;
	result = (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*)0;
	T1_ = (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*)0;
	T1_ = (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*) newObj((&NTI__KfdHSsl8vyUCSI9b3inBcww_), sizeof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ));
	result = T1_;
	initStrTable__2n9b6ELeZfbbP5wqNYm7VyA((&(*result).packageSyms));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).deps));
	initTable__w3hW0l8agm6xMv9afJe9aiRw(((NI) 32), (&(*result).importDeps));
	if ((*result).modules) { nimGCunrefNoCycle((*result).modules); (*result).modules = NIM_NIL; }
	if ((*result).importStack) { nimGCunrefNoCycle((*result).importStack); (*result).importStack = NIM_NIL; }
	initTable__CaVonymNJD1dGAhApMbV2g(((NI) 32), (&(*result).inclToMod));
	asgnRef((void**) (&(*result).config), config);
	asgnRef((void**) (&(*result).cache), cache);
	if ((*result).owners) { nimGCunrefNoCycle((*result).owners); (*result).owners = NIM_NIL; }
	if ((*result).methods) { nimGCunrefNoCycle((*result).methods); (*result).methods = NIM_NIL; }
	initStrTable__2n9b6ELeZfbbP5wqNYm7VyA((&(*result).compilerprocs));
	initStrTable__2n9b6ELeZfbbP5wqNYm7VyA((&(*result).exposed));
	asgnRef((void**) (&(*result).opNot), createMagic__MzNJxZ0htpjW89c9b2wBN5rQ(result, ((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_6), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96)));
	asgnRef((void**) (&(*result).opContains), createMagic__MzNJxZ0htpjW89c9b2wBN5rQ(result, ((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_7), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 134)));
	asgnRef((void**) (&(*result).emptyNode), newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
	(*result).recordStmt = colonanonymous___ylbbr8jh8vWSg9baXjEpyQQ;
	initTable__nbdg1XkakWibhw6meLxFVg(((NI) 32), (&(*result).cacheSeqs));
	initTable__2gDElK9agmPOHa6UVPYygZg(((NI) 32), (&(*result).cacheCounters));
	initTable__Qp2wzR51fqIFP8LjGKEktQ(((NI) 32), (&(*result).cacheTables));
	initTable__SkNpgL9chjNeAljrvOTzV2Q(((NI) 32), (&(*result).canonTypes));
	initTable__DqzDsZYrt3ZYs1snAP7Uqw(((NI) 32), (&(*result).symBodyHashes));
	return result;
}
static N_INLINE(NI, dependsOn__y2JUh31ZM6T6tGwecq9aq6Amodulegraphs)(NI a, NI b) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)((NU64)(a) << (NU64)(((NI) 15))) + b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addDep__cCI0fqtTipEqkPEycgnc9cg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 dep) {
	{
		NI T5_;
		if (!(*g).suggestMode) goto LA3_;
		T5_ = (NI)0;
		T5_ = dependsOn__y2JUh31ZM6T6tGwecq9aq6Amodulegraphs((*m).position, ((NI) (dep)));
		incl__jENnK9c9bPE73pKmo2vYjpqg((&(*g).deps), T5_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addIncludeDep__sRGnaJBZsj1fPp3iXseulA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NI32 module, NI32 includeFile) {
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = hasKeyOrPut__WdnGwzJoNnsIHUzxAKLE9aw((&(*g).inclToMod), includeFile, module);
	(void)(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__M1TGnt0pSqOaMTLwmaJc6A)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NI32 fileIdx) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI32) 0) <= fileIdx);
		if (!(T3_)) goto LA4_;
		T5_ = ((*g).modules ? (*g).modules->Sup.len : 0);
		T3_ = (((NI) (fileIdx)) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		result = (*g).modules->data[fileIdx];
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDirty__gr6489cOEwVr6TfMdoo7GTw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (*g).suggestMode;
	if (!(T1_)) goto LA2_;
	T1_ = (((*m).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitiveClosure__8rdBNRdm9adY9cVlc8PBy62w)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* g, NI n) {
	{
		NI k;
		NI i;
		k = (NI)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < n)) goto LA3;
				k = i;
				{
					NI i_2;
					NI i_3;
					i_2 = (NI)0;
					i_3 = ((NI) 0);
					{
						while (1) {
							if (!(i_3 < n)) goto LA6;
							i_2 = i_3;
							{
								NI j;
								NI i_4;
								j = (NI)0;
								i_4 = ((NI) 0);
								{
									while (1) {
										if (!(i_4 < n)) goto LA9;
										j = i_4;
										{
											NIM_BOOL T12_;
											NI T14_;
											NIM_BOOL T15_;
											T12_ = (NIM_BOOL)0;
											T12_ = !((i_2 == j));
											if (!(T12_)) goto LA13_;
											T14_ = (NI)0;
											T14_ = dependsOn__y2JUh31ZM6T6tGwecq9aq6Amodulegraphs(i_2, j);
											T15_ = (NIM_BOOL)0;
											T15_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*g)), T14_);
											T12_ = !(T15_);
											LA13_: ;
											if (!T12_) goto LA16_;
											{
												NIM_BOOL T20_;
												NI T21_;
												NI T23_;
												NI T26_;
												T20_ = (NIM_BOOL)0;
												T21_ = (NI)0;
												T21_ = dependsOn__y2JUh31ZM6T6tGwecq9aq6Amodulegraphs(i_2, k);
												T20_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*g)), T21_);
												if (!(T20_)) goto LA22_;
												T23_ = (NI)0;
												T23_ = dependsOn__y2JUh31ZM6T6tGwecq9aq6Amodulegraphs(k, j);
												T20_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*g)), T23_);
												LA22_: ;
												if (!T20_) goto LA24_;
												T26_ = (NI)0;
												T26_ = dependsOn__y2JUh31ZM6T6tGwecq9aq6Amodulegraphs(i_2, j);
												incl__jENnK9c9bPE73pKmo2vYjpqg(g, T26_);
											}
											LA24_: ;
										}
										LA16_: ;
										i_4 += ((NI) 1);
									} LA9: ;
								}
							}
							i_3 += ((NI) 1);
						} LA6: ;
					}
				}
				i += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, markClientsDirty__gLr5oeGR5aDtAVYJdMe5wg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NI32 fileIdx) {
	{
		NI T5_;
		if (!(*g).invalidTransitiveClosure) goto LA3_;
		(*g).invalidTransitiveClosure = NIM_FALSE;
		T5_ = ((*g).modules ? (*g).modules->Sup.len : 0);
		transitiveClosure__8rdBNRdm9adY9cVlc8PBy62w((&(*g).deps), T5_);
	}
	LA3_: ;
	{
		NI32 i;
		NI32 colontmp_;
		NI T7_;
		NI32 res;
		i = (NI32)0;
		colontmp_ = (NI32)0;
		T7_ = ((*g).modules ? (*g).modules->Sup.len : 0);
		colontmp_ = ((NI32) (T7_));
		res = ((NI32) 0);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
				if (!(res < colontmp_)) goto LA9;
				i = res;
				m = (*g).modules->data[i];
				{
					NIM_BOOL T12_;
					NI T14_;
					T12_ = (NIM_BOOL)0;
					T12_ = !((m == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					if (!(T12_)) goto LA13_;
					T14_ = (NI)0;
					T14_ = dependsOn__y2JUh31ZM6T6tGwecq9aq6Amodulegraphs(((NI) (i)), ((NI) (fileIdx)));
					T12_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*g).deps), T14_);
					LA13_: ;
					if (!T12_) goto LA15_;
					(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11)) & 63);
				}
				LA15_: ;
				res += ((NI) 1);
			} LA9: ;
		}
	}
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toBase64a__vUDU9aiIT31gTQwrDG6XJ8Q)(NCSTRING s, NI len) {
	NimStringDesc* result;
	NI i;
	result = (NimStringDesc*)0;
	result = rawNewString(((NI) ((NI)((NI)((NI)(len + ((NI) 2)) / ((NI) 3)) * ((NI) 4)))));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__vJDjRhiQWnfbAi9csscWSug_8));
	i = ((NI) 0);
	{
		while (1) {
			NI a;
			NI b;
			NI c;
			if (!(i < (NI)(len - ((NI) 2)))) goto LA2;
			a = ((NU8)(s[i]));
			b = ((NU8)(s[(NI)(i + ((NI) 1))]));
			c = ((NU8)(s[(NI)(i + ((NI) 2))]));
			result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a) >> (NU64)(((NI) 2))))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a) >> (NU64)(((NI) 2))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a) >> (NU64)(((NI) 2))))- 0]);
			result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(a & ((NI) 3))) << (NU64)(((NI) 4))) | (NI)((NI64)((NI)(b & ((NI) 240))) >> (NU64)(((NI) 4)))))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(a & ((NI) 3))) << (NU64)(((NI) 4))) | (NI)((NI64)((NI)(b & ((NI) 240))) >> (NU64)(((NI) 4)))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(a & ((NI) 3))) << (NU64)(((NI) 4))) | (NI)((NI64)((NI)(b & ((NI) 240))) >> (NU64)(((NI) 4)))))- 0]);
			result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(b & ((NI) 15))) << (NU64)(((NI) 2))) | (NI)((NI64)((NI)(c & ((NI) 192))) >> (NU64)(((NI) 6)))))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(b & ((NI) 15))) << (NU64)(((NI) 2))) | (NI)((NI64)((NI)(c & ((NI) 192))) >> (NU64)(((NI) 6)))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(b & ((NI) 15))) << (NU64)(((NI) 2))) | (NI)((NI64)((NI)(c & ((NI) 192))) >> (NU64)(((NI) 6)))))- 0]);
			result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)(c & ((NI) 63)))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)(c & ((NI) 63)))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)(c & ((NI) 63)))- 0]);
			i += ((NI) 3);
		} LA2: ;
	}
	{
		NI a_2;
		NI b_2;
		if (!(i < (NI)(len - ((NI) 1)))) goto LA5_;
		a_2 = ((NU8)(s[i]));
		b_2 = ((NU8)(s[(NI)(i + ((NI) 1))]));
		result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a_2) >> (NU64)(((NI) 2))))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a_2) >> (NU64)(((NI) 2))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a_2) >> (NU64)(((NI) 2))))- 0]);
		result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(a_2 & ((NI) 3))) << (NU64)(((NI) 4))) | (NI)((NI64)((NI)(b_2 & ((NI) 240))) >> (NU64)(((NI) 4)))))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(a_2 & ((NI) 3))) << (NU64)(((NI) 4))) | (NI)((NI64)((NI)(b_2 & ((NI) 240))) >> (NU64)(((NI) 4)))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI)((NU64)((NI)(a_2 & ((NI) 3))) << (NU64)(((NI) 4))) | (NI)((NI64)((NI)(b_2 & ((NI) 240))) >> (NU64)(((NI) 4)))))- 0]);
		result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NU64)((NI)(b_2 & ((NI) 15))) << (NU64)(((NI) 2))))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NU64)((NI)(b_2 & ((NI) 15))) << (NU64)(((NI) 2))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NU64)((NI)(b_2 & ((NI) 15))) << (NU64)(((NI) 2))))- 0]);
	}
	goto LA3_;
	LA5_: ;
	{
		NI a_3;
		if (!(i < len)) goto LA8_;
		a_3 = ((NU8)(s[i]));
		result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a_3) >> (NU64)(((NI) 2))))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a_3) >> (NU64)(((NI) 2))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NI64)(a_3) >> (NU64)(((NI) 2))))- 0]);
		result = resizeString(result, (cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NU64)((NI)(a_3 & ((NI) 3))) << (NU64)(((NI) 4))))- 0] ? cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NU64)((NI)(a_3 & ((NI) 3))) << (NU64)(((NI) 4))))- 0]->Sup.len : 0) + 0);
appendString(result, cb64__FJ8E6h9cW5QacFEq9be79cTmg[((NI)((NU64)((NI)(a_3 & ((NI) 3))) << (NU64)(((NI) 4))))- 0]);
	}
	goto LA3_;
	LA8_: ;
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___0A9bslyIJ49bWrftLGh13rvg)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = toBase64a__vUDU9aiIT31gTQwrDG6XJ8Q(((NCSTRING) (u)), ((NI) 16));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, hash__XFPFecV5bGJUDhwku4bw7A)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u) {
	NI result;
	result = (NI)0;
	result = ((NI) 0);
	{
		NI x;
		NI res;
		x = (NI)0;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= ((NI) 3))) goto LA3;
				x = res;
				result = (NI)((NI)((NU64)(result) << (NU64)(((NI) 8))) | ((NI) (u[(x)- 0])));
				res += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___76rDYGuUQDl2xSav8vUDiA)(tyArray__qtqsWM5aXmcpMIVmvq3kAA a, tyArray__qtqsWM5aXmcpMIVmvq3kAA b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) (a)), ((void*) (b)), ((NI) 16));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_modulegraphsDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__vJDjRhiQWnfbAi9csscWSug_2_40[40];
static TNimNode* TM__vJDjRhiQWnfbAi9csscWSug_3_2[2];
static TNimNode* TM__vJDjRhiQWnfbAi9csscWSug_4_2[2];
static TNimNode* TM__vJDjRhiQWnfbAi9csscWSug_5_4[4];
static TNimNode TM__vJDjRhiQWnfbAi9csscWSug_0[53];

/* section: NIM_merge_TYPE_INIT3 */
NTI__RZI3hCs0FTPYx8StfC81qQ_.size = sizeof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ);
NTI__RZI3hCs0FTPYx8StfC81qQ_.align = NIM_ALIGNOF(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ);
NTI__RZI3hCs0FTPYx8StfC81qQ_.kind = 18;
NTI__RZI3hCs0FTPYx8StfC81qQ_.base = 0;
TM__vJDjRhiQWnfbAi9csscWSug_2_40[0] = &TM__vJDjRhiQWnfbAi9csscWSug_0[1];
NTI__DfgJFJEYoj4YBAHLZPl5lQ_.size = sizeof(tySequence__DfgJFJEYoj4YBAHLZPl5lQ*);
NTI__DfgJFJEYoj4YBAHLZPl5lQ_.align = NIM_ALIGNOF(tySequence__DfgJFJEYoj4YBAHLZPl5lQ*);
NTI__DfgJFJEYoj4YBAHLZPl5lQ_.kind = 24;
NTI__DfgJFJEYoj4YBAHLZPl5lQ_.base = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
NTI__DfgJFJEYoj4YBAHLZPl5lQ_.flags = 2;
NTI__DfgJFJEYoj4YBAHLZPl5lQ_.marker = Marker_tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
TM__vJDjRhiQWnfbAi9csscWSug_0[1].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[1].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, modules);
TM__vJDjRhiQWnfbAi9csscWSug_0[1].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[1].name = "modules";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[1] = &TM__vJDjRhiQWnfbAi9csscWSug_0[2];
TM__vJDjRhiQWnfbAi9csscWSug_0[2].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[2].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, packageSyms);
TM__vJDjRhiQWnfbAi9csscWSug_0[2].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[2].name = "packageSyms";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[2] = &TM__vJDjRhiQWnfbAi9csscWSug_0[3];
TM__vJDjRhiQWnfbAi9csscWSug_0[3].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[3].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, deps);
TM__vJDjRhiQWnfbAi9csscWSug_0[3].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__vJDjRhiQWnfbAi9csscWSug_0[3].name = "deps";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[3] = &TM__vJDjRhiQWnfbAi9csscWSug_0[4];
NTI__48JTohSgTy339bRxHzUD8KA_.size = sizeof(tySequence__48JTohSgTy339bRxHzUD8KA*);
NTI__48JTohSgTy339bRxHzUD8KA_.align = NIM_ALIGNOF(tySequence__48JTohSgTy339bRxHzUD8KA*);
NTI__48JTohSgTy339bRxHzUD8KA_.kind = 24;
NTI__48JTohSgTy339bRxHzUD8KA_.base = (&NTI__sVg18TP9cLifHyygRe9cro9aA_);
NTI__48JTohSgTy339bRxHzUD8KA_.flags = 2;
NTI__48JTohSgTy339bRxHzUD8KA_.marker = Marker_tySequence__48JTohSgTy339bRxHzUD8KA;
TM__vJDjRhiQWnfbAi9csscWSug_0[4].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[4].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, importDeps);
TM__vJDjRhiQWnfbAi9csscWSug_0[4].typ = (&NTI__fdKWDDO1P17zvuQPReVgRA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[4].name = "importDeps";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[4] = &TM__vJDjRhiQWnfbAi9csscWSug_0[5];
TM__vJDjRhiQWnfbAi9csscWSug_0[5].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[5].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, suggestMode);
TM__vJDjRhiQWnfbAi9csscWSug_0[5].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[5].name = "suggestMode";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[5] = &TM__vJDjRhiQWnfbAi9csscWSug_0[6];
TM__vJDjRhiQWnfbAi9csscWSug_0[6].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[6].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, invalidTransitiveClosure);
TM__vJDjRhiQWnfbAi9csscWSug_0[6].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[6].name = "invalidTransitiveClosure";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[6] = &TM__vJDjRhiQWnfbAi9csscWSug_0[7];
TM__vJDjRhiQWnfbAi9csscWSug_0[7].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[7].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, inclToMod);
TM__vJDjRhiQWnfbAi9csscWSug_0[7].typ = (&NTI__e2Ciu0s1q49aVQ7ULXy7l9bQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[7].name = "inclToMod";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[7] = &TM__vJDjRhiQWnfbAi9csscWSug_0[8];
TM__vJDjRhiQWnfbAi9csscWSug_0[8].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[8].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, importStack);
TM__vJDjRhiQWnfbAi9csscWSug_0[8].typ = (&NTI__48JTohSgTy339bRxHzUD8KA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[8].name = "importStack";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[8] = &TM__vJDjRhiQWnfbAi9csscWSug_0[9];
TM__vJDjRhiQWnfbAi9csscWSug_0[9].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[9].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, backend);
TM__vJDjRhiQWnfbAi9csscWSug_0[9].typ = (&NTI__0vJvi4uHbxjbxlkkX7P1EA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[9].name = "backend";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[9] = &TM__vJDjRhiQWnfbAi9csscWSug_0[10];
TM__vJDjRhiQWnfbAi9csscWSug_0[10].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[10].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, config);
TM__vJDjRhiQWnfbAi9csscWSug_0[10].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[10].name = "config";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[10] = &TM__vJDjRhiQWnfbAi9csscWSug_0[11];
TM__vJDjRhiQWnfbAi9csscWSug_0[11].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[11].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, cache);
TM__vJDjRhiQWnfbAi9csscWSug_0[11].typ = (&NTI__lnkYNZP9asc88UfiEGjLrbA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[11].name = "cache";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[11] = &TM__vJDjRhiQWnfbAi9csscWSug_0[12];
TM__vJDjRhiQWnfbAi9csscWSug_0[12].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[12].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, vm);
TM__vJDjRhiQWnfbAi9csscWSug_0[12].typ = (&NTI__0vJvi4uHbxjbxlkkX7P1EA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[12].name = "vm";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[12] = &TM__vJDjRhiQWnfbAi9csscWSug_0[13];
NTI__In3g79a0qTcRmbTbJp9ba9ctg_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__In3g79a0qTcRmbTbJp9ba9ctg_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__In3g79a0qTcRmbTbJp9ba9ctg_.kind = 18;
NTI__In3g79a0qTcRmbTbJp9ba9ctg_.base = 0;
TM__vJDjRhiQWnfbAi9csscWSug_3_2[0] = &TM__vJDjRhiQWnfbAi9csscWSug_0[15];
TM__vJDjRhiQWnfbAi9csscWSug_0[15].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[15].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__vJDjRhiQWnfbAi9csscWSug_0[15].typ = (&NTI__vr5DoT1jILTGdRlYv1OYpw_);
TM__vJDjRhiQWnfbAi9csscWSug_0[15].name = "Field0";
TM__vJDjRhiQWnfbAi9csscWSug_3_2[1] = &TM__vJDjRhiQWnfbAi9csscWSug_0[16];
TM__vJDjRhiQWnfbAi9csscWSug_0[16].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[16].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__vJDjRhiQWnfbAi9csscWSug_0[16].typ = (&NTI__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[16].name = "Field1";
TM__vJDjRhiQWnfbAi9csscWSug_0[14].len = 2; TM__vJDjRhiQWnfbAi9csscWSug_0[14].kind = 2; TM__vJDjRhiQWnfbAi9csscWSug_0[14].sons = &TM__vJDjRhiQWnfbAi9csscWSug_3_2[0];
NTI__In3g79a0qTcRmbTbJp9ba9ctg_.node = &TM__vJDjRhiQWnfbAi9csscWSug_0[14];
TM__vJDjRhiQWnfbAi9csscWSug_0[13].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[13].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, doStopCompile);
TM__vJDjRhiQWnfbAi9csscWSug_0[13].typ = (&NTI__In3g79a0qTcRmbTbJp9ba9ctg_);
TM__vJDjRhiQWnfbAi9csscWSug_0[13].name = "doStopCompile";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[13] = &TM__vJDjRhiQWnfbAi9csscWSug_0[17];
TM__vJDjRhiQWnfbAi9csscWSug_0[17].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[17].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, usageSym);
TM__vJDjRhiQWnfbAi9csscWSug_0[17].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[17].name = "usageSym";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[14] = &TM__vJDjRhiQWnfbAi9csscWSug_0[18];
TM__vJDjRhiQWnfbAi9csscWSug_0[18].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[18].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, owners);
TM__vJDjRhiQWnfbAi9csscWSug_0[18].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[18].name = "owners";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[15] = &TM__vJDjRhiQWnfbAi9csscWSug_0[19];
NTI__quA39a2QdEQU9cSEIUSibApQ_.size = sizeof(tyTuple__quA39a2QdEQU9cSEIUSibApQ);
NTI__quA39a2QdEQU9cSEIUSibApQ_.align = NIM_ALIGNOF(tyTuple__quA39a2QdEQU9cSEIUSibApQ);
NTI__quA39a2QdEQU9cSEIUSibApQ_.kind = 18;
NTI__quA39a2QdEQU9cSEIUSibApQ_.base = 0;
NTI__quA39a2QdEQU9cSEIUSibApQ_.flags = 2;
TM__vJDjRhiQWnfbAi9csscWSug_4_2[0] = &TM__vJDjRhiQWnfbAi9csscWSug_0[21];
TM__vJDjRhiQWnfbAi9csscWSug_0[21].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[21].offset = offsetof(tyTuple__quA39a2QdEQU9cSEIUSibApQ, Field0);
TM__vJDjRhiQWnfbAi9csscWSug_0[21].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[21].name = "Field0";
TM__vJDjRhiQWnfbAi9csscWSug_4_2[1] = &TM__vJDjRhiQWnfbAi9csscWSug_0[22];
TM__vJDjRhiQWnfbAi9csscWSug_0[22].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[22].offset = offsetof(tyTuple__quA39a2QdEQU9cSEIUSibApQ, Field1);
TM__vJDjRhiQWnfbAi9csscWSug_0[22].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[22].name = "Field1";
TM__vJDjRhiQWnfbAi9csscWSug_0[20].len = 2; TM__vJDjRhiQWnfbAi9csscWSug_0[20].kind = 2; TM__vJDjRhiQWnfbAi9csscWSug_0[20].sons = &TM__vJDjRhiQWnfbAi9csscWSug_4_2[0];
NTI__quA39a2QdEQU9cSEIUSibApQ_.node = &TM__vJDjRhiQWnfbAi9csscWSug_0[20];
NTI__bWZXqEvLFwhLvAqSRoFNgQ_.size = sizeof(tySequence__bWZXqEvLFwhLvAqSRoFNgQ*);
NTI__bWZXqEvLFwhLvAqSRoFNgQ_.align = NIM_ALIGNOF(tySequence__bWZXqEvLFwhLvAqSRoFNgQ*);
NTI__bWZXqEvLFwhLvAqSRoFNgQ_.kind = 24;
NTI__bWZXqEvLFwhLvAqSRoFNgQ_.base = (&NTI__quA39a2QdEQU9cSEIUSibApQ_);
NTI__bWZXqEvLFwhLvAqSRoFNgQ_.flags = 2;
NTI__bWZXqEvLFwhLvAqSRoFNgQ_.marker = Marker_tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
TM__vJDjRhiQWnfbAi9csscWSug_0[19].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[19].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, methods);
TM__vJDjRhiQWnfbAi9csscWSug_0[19].typ = (&NTI__bWZXqEvLFwhLvAqSRoFNgQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[19].name = "methods";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[16] = &TM__vJDjRhiQWnfbAi9csscWSug_0[23];
TM__vJDjRhiQWnfbAi9csscWSug_0[23].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[23].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, systemModule);
TM__vJDjRhiQWnfbAi9csscWSug_0[23].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[23].name = "systemModule";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[17] = &TM__vJDjRhiQWnfbAi9csscWSug_0[24];
NTI__OLX364rHC66WkzRbMp49aQg_.size = sizeof(tyArray__OLX364rHC66WkzRbMp49aQg);
NTI__OLX364rHC66WkzRbMp49aQg_.align = NIM_ALIGNOF(tyArray__OLX364rHC66WkzRbMp49aQg);
NTI__OLX364rHC66WkzRbMp49aQg_.kind = 16;
NTI__OLX364rHC66WkzRbMp49aQg_.base = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
NTI__OLX364rHC66WkzRbMp49aQg_.flags = 2;
TM__vJDjRhiQWnfbAi9csscWSug_0[24].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[24].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, sysTypes);
TM__vJDjRhiQWnfbAi9csscWSug_0[24].typ = (&NTI__OLX364rHC66WkzRbMp49aQg_);
TM__vJDjRhiQWnfbAi9csscWSug_0[24].name = "sysTypes";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[18] = &TM__vJDjRhiQWnfbAi9csscWSug_0[25];
TM__vJDjRhiQWnfbAi9csscWSug_0[25].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[25].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, compilerprocs);
TM__vJDjRhiQWnfbAi9csscWSug_0[25].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[25].name = "compilerprocs";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[19] = &TM__vJDjRhiQWnfbAi9csscWSug_0[26];
TM__vJDjRhiQWnfbAi9csscWSug_0[26].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[26].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, exposed);
TM__vJDjRhiQWnfbAi9csscWSug_0[26].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[26].name = "exposed";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[20] = &TM__vJDjRhiQWnfbAi9csscWSug_0[27];
NTI__6GDJmNRiFxkWAAdMgUie8g_.size = sizeof(tyArray__6GDJmNRiFxkWAAdMgUie8g);
NTI__6GDJmNRiFxkWAAdMgUie8g_.align = NIM_ALIGNOF(tyArray__6GDJmNRiFxkWAAdMgUie8g);
NTI__6GDJmNRiFxkWAAdMgUie8g_.kind = 16;
NTI__6GDJmNRiFxkWAAdMgUie8g_.base = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
NTI__6GDJmNRiFxkWAAdMgUie8g_.flags = 2;
TM__vJDjRhiQWnfbAi9csscWSug_0[27].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[27].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, intTypeCache);
TM__vJDjRhiQWnfbAi9csscWSug_0[27].typ = (&NTI__6GDJmNRiFxkWAAdMgUie8g_);
TM__vJDjRhiQWnfbAi9csscWSug_0[27].name = "intTypeCache";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[21] = &TM__vJDjRhiQWnfbAi9csscWSug_0[28];
TM__vJDjRhiQWnfbAi9csscWSug_0[28].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[28].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, opContains);
TM__vJDjRhiQWnfbAi9csscWSug_0[28].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[28].name = "opContains";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[22] = &TM__vJDjRhiQWnfbAi9csscWSug_0[29];
TM__vJDjRhiQWnfbAi9csscWSug_0[29].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[29].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, opNot);
TM__vJDjRhiQWnfbAi9csscWSug_0[29].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[29].name = "opNot";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[23] = &TM__vJDjRhiQWnfbAi9csscWSug_0[30];
TM__vJDjRhiQWnfbAi9csscWSug_0[30].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[30].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, emptyNode);
TM__vJDjRhiQWnfbAi9csscWSug_0[30].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__vJDjRhiQWnfbAi9csscWSug_0[30].name = "emptyNode";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[24] = &TM__vJDjRhiQWnfbAi9csscWSug_0[31];
TM__vJDjRhiQWnfbAi9csscWSug_0[31].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[31].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, incr);
TM__vJDjRhiQWnfbAi9csscWSug_0[31].typ = (&NTI__sdH7TnbKACuAzE7DBabnCA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[31].name = "incr";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[25] = &TM__vJDjRhiQWnfbAi9csscWSug_0[32];
TM__vJDjRhiQWnfbAi9csscWSug_0[32].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[32].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, canonTypes);
TM__vJDjRhiQWnfbAi9csscWSug_0[32].typ = (&NTI__IioUJGdqPI6xC7S7QF8MBw_);
TM__vJDjRhiQWnfbAi9csscWSug_0[32].name = "canonTypes";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[26] = &TM__vJDjRhiQWnfbAi9csscWSug_0[33];
TM__vJDjRhiQWnfbAi9csscWSug_0[33].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[33].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, symBodyHashes);
TM__vJDjRhiQWnfbAi9csscWSug_0[33].typ = (&NTI__G1v8c16HePOldLeucwe05Q_);
TM__vJDjRhiQWnfbAi9csscWSug_0[33].name = "symBodyHashes";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[27] = &TM__vJDjRhiQWnfbAi9csscWSug_0[34];
NTI__c6vdo1yHyj19b9bS17tijS2w_.size = sizeof(tyProc__c6vdo1yHyj19b9bS17tijS2w);
NTI__c6vdo1yHyj19b9bS17tijS2w_.align = NIM_ALIGNOF(tyProc__c6vdo1yHyj19b9bS17tijS2w);
NTI__c6vdo1yHyj19b9bS17tijS2w_.kind = 25;
NTI__c6vdo1yHyj19b9bS17tijS2w_.base = 0;
NTI__c6vdo1yHyj19b9bS17tijS2w_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_0[34].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[34].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, importModuleCallback);
TM__vJDjRhiQWnfbAi9csscWSug_0[34].typ = (&NTI__c6vdo1yHyj19b9bS17tijS2w_);
TM__vJDjRhiQWnfbAi9csscWSug_0[34].name = "importModuleCallback";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[28] = &TM__vJDjRhiQWnfbAi9csscWSug_0[35];
NTI__d5yEkT9aXkAtHvVerr7IeCQ_.size = sizeof(tyProc__d5yEkT9aXkAtHvVerr7IeCQ);
NTI__d5yEkT9aXkAtHvVerr7IeCQ_.align = NIM_ALIGNOF(tyProc__d5yEkT9aXkAtHvVerr7IeCQ);
NTI__d5yEkT9aXkAtHvVerr7IeCQ_.kind = 25;
NTI__d5yEkT9aXkAtHvVerr7IeCQ_.base = 0;
NTI__d5yEkT9aXkAtHvVerr7IeCQ_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_0[35].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[35].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, includeFileCallback);
TM__vJDjRhiQWnfbAi9csscWSug_0[35].typ = (&NTI__d5yEkT9aXkAtHvVerr7IeCQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[35].name = "includeFileCallback";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[29] = &TM__vJDjRhiQWnfbAi9csscWSug_0[36];
NTI__sP1I7TbCn358eLy9bX4IphA_.size = sizeof(tyProc__sP1I7TbCn358eLy9bX4IphA);
NTI__sP1I7TbCn358eLy9bX4IphA_.align = NIM_ALIGNOF(tyProc__sP1I7TbCn358eLy9bX4IphA);
NTI__sP1I7TbCn358eLy9bX4IphA_.kind = 25;
NTI__sP1I7TbCn358eLy9bX4IphA_.base = 0;
NTI__sP1I7TbCn358eLy9bX4IphA_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_0[36].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[36].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, recordStmt);
TM__vJDjRhiQWnfbAi9csscWSug_0[36].typ = (&NTI__sP1I7TbCn358eLy9bX4IphA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[36].name = "recordStmt";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[30] = &TM__vJDjRhiQWnfbAi9csscWSug_0[37];
TM__vJDjRhiQWnfbAi9csscWSug_0[37].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[37].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, cacheSeqs);
TM__vJDjRhiQWnfbAi9csscWSug_0[37].typ = (&NTI__0Y2brGGKD9bV6GJLXT9aUDgA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[37].name = "cacheSeqs";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[31] = &TM__vJDjRhiQWnfbAi9csscWSug_0[38];
TM__vJDjRhiQWnfbAi9csscWSug_0[38].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[38].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, cacheCounters);
TM__vJDjRhiQWnfbAi9csscWSug_0[38].typ = (&NTI__NttoEzoiq5CiphZe81oadg_);
TM__vJDjRhiQWnfbAi9csscWSug_0[38].name = "cacheCounters";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[32] = &TM__vJDjRhiQWnfbAi9csscWSug_0[39];
TM__vJDjRhiQWnfbAi9csscWSug_0[39].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[39].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, cacheTables);
TM__vJDjRhiQWnfbAi9csscWSug_0[39].typ = (&NTI__nagDFX4QHx0s6Fvma9blmSg_);
TM__vJDjRhiQWnfbAi9csscWSug_0[39].name = "cacheTables";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[33] = &TM__vJDjRhiQWnfbAi9csscWSug_0[40];
NTI__euPCXX9bc3XzndEhYlqNS7g_.size = sizeof(tyTuple__euPCXX9bc3XzndEhYlqNS7g);
NTI__euPCXX9bc3XzndEhYlqNS7g_.align = NIM_ALIGNOF(tyTuple__euPCXX9bc3XzndEhYlqNS7g);
NTI__euPCXX9bc3XzndEhYlqNS7g_.kind = 18;
NTI__euPCXX9bc3XzndEhYlqNS7g_.base = 0;
NTI__euPCXX9bc3XzndEhYlqNS7g_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_5_4[0] = &TM__vJDjRhiQWnfbAi9csscWSug_0[42];
NTI__8ooe5vdoqmvpHnfXV29bP3w_.size = sizeof(tyProc__8ooe5vdoqmvpHnfXV29bP3w);
NTI__8ooe5vdoqmvpHnfXV29bP3w_.align = NIM_ALIGNOF(tyProc__8ooe5vdoqmvpHnfXV29bP3w);
NTI__8ooe5vdoqmvpHnfXV29bP3w_.kind = 25;
NTI__8ooe5vdoqmvpHnfXV29bP3w_.base = 0;
NTI__8ooe5vdoqmvpHnfXV29bP3w_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_0[42].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[42].offset = offsetof(tyTuple__euPCXX9bc3XzndEhYlqNS7g, Field0);
TM__vJDjRhiQWnfbAi9csscWSug_0[42].typ = (&NTI__8ooe5vdoqmvpHnfXV29bP3w_);
TM__vJDjRhiQWnfbAi9csscWSug_0[42].name = "Field0";
TM__vJDjRhiQWnfbAi9csscWSug_5_4[1] = &TM__vJDjRhiQWnfbAi9csscWSug_0[43];
NTI__A7Sdoem70tRxSEmKrf9cmyg_.size = sizeof(tyProc__A7Sdoem70tRxSEmKrf9cmyg);
NTI__A7Sdoem70tRxSEmKrf9cmyg_.align = NIM_ALIGNOF(tyProc__A7Sdoem70tRxSEmKrf9cmyg);
NTI__A7Sdoem70tRxSEmKrf9cmyg_.kind = 25;
NTI__A7Sdoem70tRxSEmKrf9cmyg_.base = 0;
NTI__A7Sdoem70tRxSEmKrf9cmyg_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_0[43].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[43].offset = offsetof(tyTuple__euPCXX9bc3XzndEhYlqNS7g, Field1);
TM__vJDjRhiQWnfbAi9csscWSug_0[43].typ = (&NTI__A7Sdoem70tRxSEmKrf9cmyg_);
TM__vJDjRhiQWnfbAi9csscWSug_0[43].name = "Field1";
TM__vJDjRhiQWnfbAi9csscWSug_5_4[2] = &TM__vJDjRhiQWnfbAi9csscWSug_0[44];
NTI__EAEKmBUgKFg29agoUGtzDEQ_.size = sizeof(tyProc__EAEKmBUgKFg29agoUGtzDEQ);
NTI__EAEKmBUgKFg29agoUGtzDEQ_.align = NIM_ALIGNOF(tyProc__EAEKmBUgKFg29agoUGtzDEQ);
NTI__EAEKmBUgKFg29agoUGtzDEQ_.kind = 25;
NTI__EAEKmBUgKFg29agoUGtzDEQ_.base = 0;
NTI__EAEKmBUgKFg29agoUGtzDEQ_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_0[44].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[44].offset = offsetof(tyTuple__euPCXX9bc3XzndEhYlqNS7g, Field2);
TM__vJDjRhiQWnfbAi9csscWSug_0[44].typ = (&NTI__EAEKmBUgKFg29agoUGtzDEQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[44].name = "Field2";
TM__vJDjRhiQWnfbAi9csscWSug_5_4[3] = &TM__vJDjRhiQWnfbAi9csscWSug_0[45];
TM__vJDjRhiQWnfbAi9csscWSug_0[45].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[45].offset = offsetof(tyTuple__euPCXX9bc3XzndEhYlqNS7g, Field3);
TM__vJDjRhiQWnfbAi9csscWSug_0[45].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[45].name = "Field3";
TM__vJDjRhiQWnfbAi9csscWSug_0[41].len = 4; TM__vJDjRhiQWnfbAi9csscWSug_0[41].kind = 2; TM__vJDjRhiQWnfbAi9csscWSug_0[41].sons = &TM__vJDjRhiQWnfbAi9csscWSug_5_4[0];
NTI__euPCXX9bc3XzndEhYlqNS7g_.node = &TM__vJDjRhiQWnfbAi9csscWSug_0[41];
NTI__PzqTLBFNawCGiqTk0UORYw_.size = sizeof(tySequence__PzqTLBFNawCGiqTk0UORYw*);
NTI__PzqTLBFNawCGiqTk0UORYw_.align = NIM_ALIGNOF(tySequence__PzqTLBFNawCGiqTk0UORYw*);
NTI__PzqTLBFNawCGiqTk0UORYw_.kind = 24;
NTI__PzqTLBFNawCGiqTk0UORYw_.base = (&NTI__euPCXX9bc3XzndEhYlqNS7g_);
NTI__PzqTLBFNawCGiqTk0UORYw_.flags = 2;
NTI__PzqTLBFNawCGiqTk0UORYw_.marker = Marker_tySequence__PzqTLBFNawCGiqTk0UORYw;
TM__vJDjRhiQWnfbAi9csscWSug_0[40].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[40].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, passes);
TM__vJDjRhiQWnfbAi9csscWSug_0[40].typ = (&NTI__PzqTLBFNawCGiqTk0UORYw_);
TM__vJDjRhiQWnfbAi9csscWSug_0[40].name = "passes";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[34] = &TM__vJDjRhiQWnfbAi9csscWSug_0[46];
NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_.size = sizeof(tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA);
NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_.align = NIM_ALIGNOF(tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA);
NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_.kind = 25;
NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_.base = 0;
NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_0[46].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[46].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, onDefinition);
TM__vJDjRhiQWnfbAi9csscWSug_0[46].typ = (&NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[46].name = "onDefinition";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[35] = &TM__vJDjRhiQWnfbAi9csscWSug_0[47];
TM__vJDjRhiQWnfbAi9csscWSug_0[47].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[47].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, onDefinitionResolveForward);
TM__vJDjRhiQWnfbAi9csscWSug_0[47].typ = (&NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[47].name = "onDefinitionResolveForward";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[36] = &TM__vJDjRhiQWnfbAi9csscWSug_0[48];
TM__vJDjRhiQWnfbAi9csscWSug_0[48].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[48].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, onUsage);
TM__vJDjRhiQWnfbAi9csscWSug_0[48].typ = (&NTI__R9aa9aO9cNhvWgTGK9bAAvuSRA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[48].name = "onUsage";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[37] = &TM__vJDjRhiQWnfbAi9csscWSug_0[49];
TM__vJDjRhiQWnfbAi9csscWSug_0[49].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[49].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, globalDestructors);
TM__vJDjRhiQWnfbAi9csscWSug_0[49].typ = (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_);
TM__vJDjRhiQWnfbAi9csscWSug_0[49].name = "globalDestructors";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[38] = &TM__vJDjRhiQWnfbAi9csscWSug_0[50];
TM__vJDjRhiQWnfbAi9csscWSug_0[50].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[50].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, strongSemCheck);
TM__vJDjRhiQWnfbAi9csscWSug_0[50].typ = (&NTI__sP1I7TbCn358eLy9bX4IphA_);
TM__vJDjRhiQWnfbAi9csscWSug_0[50].name = "strongSemCheck";
TM__vJDjRhiQWnfbAi9csscWSug_2_40[39] = &TM__vJDjRhiQWnfbAi9csscWSug_0[51];
NTI__3TeLOx1euAsRk3YCaQCuPg_.size = sizeof(tyProc__3TeLOx1euAsRk3YCaQCuPg);
NTI__3TeLOx1euAsRk3YCaQCuPg_.align = NIM_ALIGNOF(tyProc__3TeLOx1euAsRk3YCaQCuPg);
NTI__3TeLOx1euAsRk3YCaQCuPg_.kind = 25;
NTI__3TeLOx1euAsRk3YCaQCuPg_.base = 0;
NTI__3TeLOx1euAsRk3YCaQCuPg_.flags = 3;
TM__vJDjRhiQWnfbAi9csscWSug_0[51].kind = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[51].offset = offsetof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ, compatibleProps);
TM__vJDjRhiQWnfbAi9csscWSug_0[51].typ = (&NTI__3TeLOx1euAsRk3YCaQCuPg_);
TM__vJDjRhiQWnfbAi9csscWSug_0[51].name = "compatibleProps";
TM__vJDjRhiQWnfbAi9csscWSug_0[0].len = 40; TM__vJDjRhiQWnfbAi9csscWSug_0[0].kind = 2; TM__vJDjRhiQWnfbAi9csscWSug_0[0].sons = &TM__vJDjRhiQWnfbAi9csscWSug_2_40[0];
NTI__RZI3hCs0FTPYx8StfC81qQ_.node = &TM__vJDjRhiQWnfbAi9csscWSug_0[0];
NTI__KfdHSsl8vyUCSI9b3inBcww_.size = sizeof(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*);
NTI__KfdHSsl8vyUCSI9b3inBcww_.align = NIM_ALIGNOF(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*);
NTI__KfdHSsl8vyUCSI9b3inBcww_.kind = 22;
NTI__KfdHSsl8vyUCSI9b3inBcww_.base = (&NTI__RZI3hCs0FTPYx8StfC81qQ_);
NTI__KfdHSsl8vyUCSI9b3inBcww_.marker = Marker_tyRef__KfdHSsl8vyUCSI9b3inBcww;
NTI__Hb6rFM0ecvtlLf2kv9aU75w_.size = sizeof(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w);
NTI__Hb6rFM0ecvtlLf2kv9aU75w_.align = NIM_ALIGNOF(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w);
NTI__Hb6rFM0ecvtlLf2kv9aU75w_.kind = 17;
NTI__Hb6rFM0ecvtlLf2kv9aU75w_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
NTI__Hb6rFM0ecvtlLf2kv9aU75w_.flags = 1;
TM__vJDjRhiQWnfbAi9csscWSug_0[52].len = 0; TM__vJDjRhiQWnfbAi9csscWSug_0[52].kind = 2;
NTI__Hb6rFM0ecvtlLf2kv9aU75w_.node = &TM__vJDjRhiQWnfbAi9csscWSug_0[52];
}

